@@ -3,10 +3,10 @@
 Example of custom forms
 """
 
-import floppyforms as forms
+import floppyforms.__future__ as forms
 
-from coop_cms.forms import ArticleForm as CmsArticleForm
-from coop_cms.forms import NewsletterForm
+from coop_cms.forms.articles import ArticleForm as CmsArticleForm
+from coop_cms.forms.newsletters import NewsletterForm
 from coop_cms.settings import get_article_class
 from coop_cms.models import ArticleCategory
 
@@ -16,19 +16,18 @@ class ArticleForm(CmsArticleForm):
 
     class Meta(CmsArticleForm.Meta):
         model = get_article_class()
-        fields = CmsArticleForm.Meta.fields +('author',)
+        fields = CmsArticleForm.Meta.fields + ('author',)
 
 
 class SortableNewsletterForm(NewsletterForm):
     """Example of newsletter form"""
-    #cleaned_data = None
+    # cleaned_data = None
 
     sortable = forms.CharField(required=False, widget=forms.HiddenInput())
 
     class Media(NewsletterForm.Media):
         js = NewsletterForm.Media.js + ('js/jquery.sortElements.js',)
 
-
     def save(self, *args, **kwargs):
         """override save"""
         ret = super(SortableNewsletterForm, self).save(*args, **kwargs)
