@@ -1,23 +1,25 @@
 # -*- coding: utf-8 -*-
 """forms"""
 
-import floppyforms as forms
+import floppyforms.__future__ as forms
 
-from djaloha.widgets import AlohaInput
+from coop_html_editor.widgets import get_inline_html_widget
 
 from coop_cms.apps.test_app.models import TestClass
-from coop_cms.forms import AlohaEditableModelForm, NewArticleForm, ArticleSettingsForm
+from coop_cms.forms.articles import NewArticleForm, ArticleSettingsForm
+from coop_cms.forms.base import InlineHtmlEditableModelForm
+from coop_cms.forms.newsletters import NewsletterSettingsForm
 
 
-class TestClassForm(AlohaEditableModelForm):
+class TestClassForm(InlineHtmlEditableModelForm):
     """for unit-testing"""
     class Meta:
         model = TestClass
         fields = ('field1', 'field2', 'field3', 'bool_field', 'int_field', 'float_field')
         widgets = {
-            'field2': AlohaInput(),
+            'field2': get_inline_html_widget(),
         }
-        no_aloha_widgets = ('field2', 'field3', 'bool_field', 'int_field', 'float_field')
+        no_inline_html_widgets = ('field2', 'field3', 'bool_field', 'int_field', 'float_field')
 
 
 class MyNewArticleForm(NewArticleForm):
@@ -28,3 +30,8 @@ class MyNewArticleForm(NewArticleForm):
 class MyArticleSettingsForm(ArticleSettingsForm):
     """for unit-testing"""
     dummy = forms.CharField(required=False)
+
+
+class MyNewsletterSettingsForm(NewsletterSettingsForm):
+    """for unit-testing"""
+    dummy = forms.CharField(required=False)
