@@ -3,14 +3,19 @@
 
 from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
-from django.core.urlresolvers import reverse
+from django.urls import reverse, NoReverseMatch
 from django.template.loader import get_template
 from django.utils.translation import ugettext as _
 
 from coop_bar.utils import make_link
+from coop_html_editor.settings import get_html_editor
 
 from coop_cms.models import Link, Fragment
-from coop_cms.settings import get_article_class, get_navtree_class, cms_no_homepage, hide_media_library_menu
+from coop_cms.moves import is_authenticated
+from coop_cms.settings import (
+    get_article_class, get_navtree_class, cms_no_homepage, hide_media_library_menu, is_localized
+)
+from coop_cms.utils import get_model_name, get_model_app, get_model_label
 
 
 def can_do(perm, object_names):
@@ -27,7 +32,7 @@ def can_do(perm, object_names):
 
                 if obj is not None:
 
-                    callback_name = u"coop_cms_{0}_callback".format(perm, object_name)
+                    callback_name = "coop_cms_{0}_callback".format(perm)
                     callback = context.get(callback_name, None)
 
                     if callback and request and callback():
@@ -62,20 +67,19 @@ def can_add_link(func):
     """decorator checking if user can add link"""
     def wrapper(request, context):
         """wrapper"""
-        ct = ContentType.objects.get_for_model(Link)
-        perm = '{0}.add_{1}'.format(ct.app_label, ct.model)
+        content_type = ContentType.objects.get_for_model(Link)
+        perm = '{0}.add_{1}'.format(content_type.app_label, content_type.model)
         if request and request.user.has_perm(perm):
             return func(request, context)
         return None
     return wrapper
 
-## menus
 
 def django_admin(request, context):
     """show admin"""
     if request and request.user.is_staff:
         return make_link(
-            reverse("admin:index"), _(u'Administration'), 'fugue/tables.png',
+            reverse("admin:index"), _(u'Administration'), 'table',
             classes=['icon', 'alert_on_click']
         )
 
@@ -85,9 +89,10 @@ def django_admin_edit_article(request, context):
     if request and request.user.is_staff and 'article' in context:
         article_class = get_article_class()
         article = context['article']
-        view_name = 'admin:%s_%s_change' % (article_class._meta.app_label,  article_class._meta.module_name)
+
+        view_name = 'admin:{0}_{1}_change'.format(get_model_app(article_class), get_model_name(article_class))
         return make_link(
-            reverse(view_name, args=[article.id]), _(u'Article admin'), 'fugue/table.png',
+            reverse(view_name, args=[article.id]), _('Article admin'), 'table',
             classes=['icon', 'alert_on_click']
         )
 
@@ -97,14 +102,14 @@ def django_admin_edit_object(request, context):
     if request and request.user.is_staff and context.get('object', None):
         obj = context['object']
         object_class = obj.__class__
-        view_name = 'admin:%s_%s_change' % (object_class._meta.app_label,  object_class._meta.module_name)
+        view_name = 'admin:{0}_{1}_change'.format(get_model_app(object_class), get_model_name(object_class))
         try:
             return make_link(
-                reverse(view_name, args=[object.id]),
-                _(u'Admin {0}'.format(object_class._meta.verbose_name)), 'fugue/table.png',
+                reverse(view_name, args=[obj.id]),
+                _('Admin {0}').format(get_model_label(object_class)), 'table',
                 classes=['icon', 'alert_on_click']
             )
-        except Exception:
+        except NoReverseMatch:
             pass
 
 
@@ -115,14 +120,14 @@ def django_admin_add_object(request, context):
         object_class = context.get('model', None)
         if not object_class:
             object_class = context['object'].__class__
-        view_name = 'admin:%s_%s_add' % (object_class._meta.app_label,  object_class._meta.module_name)
+        view_name = 'admin:{0}_{1}_add'.format(get_model_app(object_class), get_model_name(object_class))
         try:
             return make_link(
                 reverse(view_name),
-                _(u'Add {0}'.format(object_class._meta.verbose_name)), 'fugue/table.png',
+                _('Add {0}').format(get_model_label(object_class)), 'table',
                 classes=['icon', 'alert_on_click']
             )
-        except Exception:
+        except NoReverseMatch:
             pass
 
 
@@ -133,45 +138,45 @@ def django_admin_list_objects(request, context):
         if not object_class:
             object_class = context['object'].__class__
         try:
-            view_name = 'admin:%s_%s_changelist' % (object_class._meta.app_label,  object_class._meta.module_name)
+            view_name = 'admin:{0}_{1}_changelist'.format(get_model_app(object_class), get_model_name(object_class))
             return make_link(
                 reverse(view_name),
-                _(u'List {0}'.format(object_class._meta.verbose_name)), 'fugue/table.png',
+                _('List {0}').format(get_model_label(object_class)), 'table',
                 classes=['icon', 'alert_on_click']
             )
-        except:
+        except NoReverseMatch:
             pass
 
 
 def django_admin_navtree(request, context):
     """show menu"""
     if request and request.user.is_staff:
-        coop_cms_navtrees = context.get('coop_cms_navtrees', None)
-        if coop_cms_navtrees:
-            tree_class = get_navtree_class()
-            admin_tree_name = "{0}_{1}".format(tree_class._meta.app_label, tree_class._meta.module_name)
-            if len(coop_cms_navtrees) == 1:
-                tree = coop_cms_navtrees[0]
-                url = reverse('admin:{0}_change'.format(admin_tree_name), args=[tree.id])
-                label = _(u'Navigation tree')
-            else:
-                url = reverse('admin:{0}_changelist'.format(admin_tree_name))
-                label = _(u'Navigation trees')
-            return make_link(
-                url, label, 'fugue/leaf-plant.png',
-                classes=['icon', 'alert_on_click']
-            )
+        coop_cms_navtrees = context.get('coop_cms_navtrees', None) or []
+        tree_class = get_navtree_class()
+        admin_tree_name = "{0}_{1}".format(get_model_app(tree_class), get_model_name(tree_class))
+        if len(coop_cms_navtrees) == 1:
+            tree = coop_cms_navtrees[0]
+            url = reverse('admin:{0}_change'.format(admin_tree_name), args=[tree.id])
+            label = _('Navigation tree')
+        else:
+            url = reverse('admin:{0}_changelist'.format(admin_tree_name))
+            label = _('Navigation trees')
+        return make_link(
+            url, label, 'leaf',
+            classes=['icon', 'alert_on_click']
+        )
+
 
 def view_all_articles(request, context):
     """show menu"""
     if request and request.user.is_staff:
         return make_link(
-            reverse('coop_cms_view_all_articles'), _(u'Articles'), 'fugue/documents-stack.png',
+            reverse('coop_cms_view_all_articles'), _('Articles'), 'copy',
             classes=['icon', 'alert_on_click']
         )
 
 
-@can_edit
+@can_edit_object
 def cms_media_library(request, context):
     """show menu"""
     if hide_media_library_menu():
@@ -179,12 +184,12 @@ def cms_media_library(request, context):
     
     if context.get('edit_mode'):
         return make_link(
-            reverse('coop_cms_media_images'), _(u'Media library'), 'fugue/images-stack.png',
+            reverse('coop_cms_media_images'), _('Media library'), 'images',
             'coopbar_medialibrary', ['icon', 'slide']
         )
 
 
-@can_edit
+@can_edit_object
 def cms_upload_image(request, context):
     """show menu"""
     if hide_media_library_menu():
@@ -192,12 +197,23 @@ def cms_upload_image(request, context):
     
     if context.get('edit_mode'):
         return make_link(
-            reverse('coop_cms_upload_image'), _(u'Add image'), 'fugue/image--plus.png',
+            reverse('coop_cms_upload_image'), _('Add image'), 'file-image',
             classes=['coopbar_addfile', 'colorbox-form', 'icon']
         )
 
 
-@can_edit
+@can_edit_article
+def cms_update_logo(request, context):
+    """show menu"""
+    article = context.get('article', None)
+    if article and context.get('edit_mode'):
+        return make_link(
+            reverse('coop_cms_update_logo', args=[article.id]), _('Update logo'), 'image',
+            classes=['update-logo', 'icon']
+        )
+
+
+@can_edit_object
 def cms_upload_doc(request, context):
     """show menu"""
     if hide_media_library_menu():
@@ -205,7 +221,7 @@ def cms_upload_doc(request, context):
     
     if context.get('edit_mode'):
         return make_link(
-            reverse('coop_cms_upload_doc'), _(u'Add document'), 'fugue/document-import.png',
+            reverse('coop_cms_upload_doc'), _('Add document'), 'file-import',
             classes=['coopbar_addfile', 'colorbox-form', 'icon']
         )
 
@@ -216,7 +232,7 @@ def cms_new_article(request, context):
     if not context.get('edit_mode'):
         url = reverse('coop_cms_new_article')
         return make_link(
-            url, _(u'Add article'), 'fugue/document--plus.png',
+            url, _('Add article'), 'file-medical',
             classes=['alert_on_click', 'colorbox-form', 'icon']
         )
 
@@ -227,7 +243,7 @@ def cms_new_link(request, context):
     if not context.get('edit_mode'):
         url = reverse('coop_cms_new_link')
         return make_link(
-            url, _(u'Add link'), 'fugue/document--plus.png',
+            url, _('Add link'), 'file-medical',
             classes=['alert_on_click', 'colorbox-form', 'icon']
         )
 
@@ -242,18 +258,18 @@ def cms_set_homepage(request, context):
     if context.get('edit_mode') and article and (not getattr(article, 'is_homepage', False)):
         url = reverse('coop_cms_set_homepage', args=[article.id])
         return make_link(
-            url, _(u'Set homepage'), 'fugue/home--pencil.png',
+            url, _('Set homepage'), 'home',
             classes=['alert_on_click', 'colorbox-form', 'icon']
         )
 
 
-@can_edit_article    
+@can_edit_article
 def cms_article_settings(request, context):
     """show menu"""
     article = context['article']
     url = reverse('coop_cms_article_settings', args=[article.id])
     return make_link(
-        url, _(u'Article settings'), 'fugue/gear.png',
+        url, _('Article settings'), 'cog',
         classes=['alert_on_click', 'colorbox-form', 'icon']
     )
 
@@ -264,7 +280,7 @@ def cms_save(request, context):
     if context.get('edit_mode'):
         #No link, will be managed by catching the js click event
         return make_link(
-            '', _(u'Save'), 'fugue/disk-black.png', id="coopbar_save",
+            '', _('Save'), 'save', id="coopbar_save",
             classes=['icon']
         )
 
@@ -276,7 +292,7 @@ def cms_cancel(request, context):
         url = context.get('coop_cms_cancel_url', None)
         if url:
             return make_link(
-                url, _(u'Cancel'), 'fugue/cross.png', classes=['alert_on_click', 'icon']
+                url, _('Cancel'), 'times', classes=['alert_on_click', 'icon']
             )
 
 
@@ -287,7 +303,7 @@ def cms_edit(request, context):
         url = context.get('coop_cms_edit_url', None)
         if url:
             return make_link(
-                url, _(u'Edit'), 'fugue/document--pencil.png', classes=['icon']
+                url, _('Edit'), 'edit', classes=['icon']
             )
 
 
@@ -295,31 +311,31 @@ def cms_edit(request, context):
 def cms_publish(request, context):
     """show menu"""
     article = context.get('article')
-    if article and ('draft' in context) :
+    if article and ('draft' in context):
         if context['draft']:
             return make_link(
-                article.get_publish_url(), _(u'Draft'), 'fugue/lock.png',
+                article.get_publish_url(), _('Draft'), 'lock',
                 classes=['colorbox-form', 'icon']
             )
         else:
             return make_link(
-                article.get_publish_url(), _(u'Published'), 'fugue/globe.png',
+                article.get_publish_url(), _('Published'), 'globe-americas',
                 classes=['colorbox-form', 'icon']
             )
 
 
 def cms_extra_js(request, context):
     """add javascript code"""
-    t = get_template("coop_cms/_coop_bar_js.html")
-    return t.render(context)
+    context['html_editor'] = get_html_editor()
+    template_ = get_template("coop_cms/_coop_bar_js.html")
+    return template_.render(context)
 
 
 def log_out(request, context):
     """show menu"""
-    if request and request.user.is_authenticated() and request.user.is_staff:
+    if request and is_authenticated(request.user) and request.user.is_staff:
         return make_link(
-            reverse("django.contrib.auth.views.logout"), _(u'Log out'), 'fugue/control-power.png',
-            classes=['alert_on_click', 'icon']
+            reverse("logout"), _('Log out'), 'power-off', classes=['alert_on_click', 'icon']
         )
 
 
@@ -330,32 +346,24 @@ def cms_new_newsletter(request, context):
         if getattr(settings, 'COOP_CMS_NEWSLETTER_TEMPLATES', None):
             url = reverse('coop_cms_new_newsletter')
             return make_link(
-                url, _(u'Create newsletter'), 'fugue/document--plus.png',
+                url, _('Create newsletter'), 'file-medical',
                 classes=['alert_on_click', 'colorbox-form', 'icon']
             )
 
 
-@can_edit_newsletter
-def edit_newsletter(request, context):
-    """show menu"""
-    if not context.get('edit_mode'):
-        newsletter = context.get('newsletter')
-        return make_link(newsletter.get_edit_url(), _(u'Edit'), 'fugue/document--pencil.png', classes=['icon'])
-
-
 @can_edit_newsletter
 def newsletter_admin(request, context):
     """show menu"""
     newsletter = context.get('newsletter')
     object_class = newsletter.__class__
-    view_name = 'admin:%s_%s_change' % (object_class._meta.app_label,  object_class._meta.module_name)
+    view_name = 'admin:{0}_{1}_change'.format(get_model_app(object_class), get_model_name(object_class))
     try:
         return make_link(
             reverse(view_name, args=[newsletter.id]),
-            _(u'Admin {0}'.format(object_class._meta.verbose_name)), 'fugue/table.png',
+            _('Admin {0}').format(get_model_label(object_class)), 'table',
             classes=['icon', 'alert_on_click']
         )
-    except Exception:
+    except NoReverseMatch:
         pass
 
 
@@ -366,32 +374,13 @@ def newsletter_articles(request, context):
     try:
         return make_link(
             reverse(view_name),
-            _(u'Articles ordering'), 'fugue/table.png',
+            _('Articles ordering'), 'table',
             classes=['icon', 'alert_on_click']
         )
-    except Exception:
+    except NoReverseMatch:
         pass
 
 
-@can_edit_newsletter
-def cancel_edit_newsletter(request, context):
-    """show menu"""
-    if context.get('edit_mode'):
-        newsletter = context.get('newsletter')
-        return make_link(newsletter.get_absolute_url(), _(u'Cancel'), 'fugue/cross.png', classes=['icon'])
-
-
-@can_edit_newsletter
-def save_newsletter(request, context):
-    """show menu"""
-    post_url = context.get('post_url')
-    if context.get('edit_mode') and post_url:
-        return make_link(
-            post_url, _(u'Save'), 'fugue/disk-black.png',
-            classes=['icon', 'post-form']
-        )
-
-
 @can_edit_newsletter
 def change_newsletter_settings(request, context):
     """show menu"""
@@ -399,23 +388,21 @@ def change_newsletter_settings(request, context):
         newsletter = context.get('newsletter')
         url = reverse('coop_cms_newsletter_settings', kwargs={'newsletter_id': newsletter.id})
         return make_link(
-            url, _(u'Newsletter settings'), 'fugue/gear.png',
+            url, _('Newsletter settings'), 'cog',
             classes=['icon', 'colorbox-form', 'alert_on_click']
         )
 
 
-#DEPRECATED
 @can_edit_newsletter
-def change_newsletter_template(request, context):
+def convert_newsletter_to_pdf(request, context):
     """show menu"""
-    if context.get('edit_mode'):
+    if 'wkhtmltopdf' in settings.INSTALLED_APPS and not context.get('edit_mode'):
         newsletter = context.get('newsletter')
-        url = reverse('coop_cms_change_newsletter_template', args=[newsletter.id])
+        url = reverse('coop_cms_newsletter_pdf', args=[newsletter.id, ])
         return make_link(
-            url, _(u'Newsletter template'), 'fugue/application-blog.png',
-            classes=['alert_on_click', 'colorbox-form', 'icon']
+            url, _('Convert to Pdf'), 'file-pdf',
+            classes=['icon']
         )
-###############
 
 
 @can_edit_newsletter
@@ -425,33 +412,35 @@ def test_newsletter(request, context):
     if newsletter:
         url = reverse('coop_cms_test_newsletter', args=[newsletter.id])
         return make_link(
-            url, _(u'Send test'), 'fugue/mail-at-sign.png',
+            url, _('Send test'), 'at',
             classes=['alert_on_click', 'colorbox-form', 'icon']
         )
 
 
+@can_edit_object
 def cms_add_fragment(request, context):
     """show menu"""
     if request:
-        ct = ContentType.objects.get_for_model(Fragment)
-        perm = '{0}.add_{1}'.format(ct.app_label, ct.model)
+        content_type = ContentType.objects.get_for_model(Fragment)
+        perm = '{0}.add_{1}'.format(content_type.app_label, content_type.model)
         if request.user.has_perm(perm):
             url = reverse("coop_cms_add_fragment")
             return make_link(
-                url, _(u'Add fragment'), 'fugue/block--plus.png',
+                url, _('Add fragment'), 'cubes',
                 classes=['alert_on_click', 'colorbox-form', 'icon', 'if-fragments']
             )
 
 
+@can_edit_object
 def cms_edit_fragments(request, context):
     """show menu"""
     if request:
-        ct = ContentType.objects.get_for_model(Fragment)
-        perm = '{0}.change_{1}'.format(ct.app_label, ct.model)
+        content_type = ContentType.objects.get_for_model(Fragment)
+        perm = '{0}.change_{1}'.format(content_type.app_label, content_type.model)
         if request.user.has_perm(perm):
             url = reverse("coop_cms_edit_fragments")
             return make_link(
-                url, _(u'Edit fragments'), 'fugue/block--pencil.png',
+                url, _('Edit fragments'), 'shapes',
                 classes=['alert_on_click', 'colorbox-form', 'icon', 'if-fragments']
             )
 
@@ -460,31 +449,70 @@ def publication_css_classes(request, context):
     """define coop_bar css_class"""
     variable = context.get('article', None) or context.get('object', None)
     if variable:
-        css_classes = []
         if hasattr(variable, 'is_draft') and callable(variable.is_draft) and variable.is_draft():
             return 'is-draft'
         elif hasattr(variable, 'is_archived') and callable(variable.is_archived) and variable.is_archived():
             return 'is-archived'    
 
 
+def switch_language(request, context):
+    if request and request.user.is_staff and is_localized():
+        url = reverse('coop_cms_switch_language_popup')
+        return make_link(url, _('Switch language'), 'globe-americas', classes=['colorbox-form', 'icon'])
+
+
 def load_commands(coop_bar):
     """load commandes"""
     
-    coop_bar.register([
-        [log_out],
+    menu_list = [
         [
-            django_admin, django_admin_edit_article, django_admin_edit_object, django_admin_navtree, view_all_articles
+            log_out,
         ],
-        [cms_add_fragment, cms_edit_fragments],
-        [cms_media_library, cms_upload_image, cms_upload_doc],
         [
-            cms_new_newsletter, edit_newsletter, cancel_edit_newsletter, save_newsletter,
-            change_newsletter_settings, newsletter_admin, newsletter_articles, test_newsletter
+            django_admin,
+            django_admin_edit_article,
+            django_admin_edit_object,
+            django_admin_navtree,
+            view_all_articles,
         ],
-        [cms_edit, cms_save, cms_cancel,],
-        [cms_new_article, cms_new_link, cms_article_settings, cms_set_homepage],
-        [cms_publish],
-    ])
+        [
+            cms_add_fragment,
+            cms_edit_fragments,
+        ],
+        [
+            cms_update_logo,
+            cms_media_library,
+            cms_upload_image,
+            cms_upload_doc,
+        ],
+        [
+            cms_new_newsletter,
+            change_newsletter_settings,
+            newsletter_admin,
+            newsletter_articles,
+            test_newsletter,
+            convert_newsletter_to_pdf,
+        ],
+        [
+            cms_edit,
+            cms_save,
+            cms_cancel,
+        ],
+        [
+            cms_new_article,
+            cms_new_link,
+            cms_article_settings,
+            cms_set_homepage
+        ],
+        [
+            cms_publish,
+        ],
+        [
+            switch_language,
+        ],
+    ]
+
+    coop_bar.register(menu_list)
     
     coop_bar.register_css_classes(publication_css_classes)
     
