@@ -1,24 +1,25 @@
 # -*- coding: utf-8 -*-
 """generic views"""
 
-import logging
-
+from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.messages.api import success as success_message, error as error_message
+from django.core.cache import cache
 from django.core.exceptions import PermissionDenied
-from django.core.urlresolvers import reverse
 from django.forms.models import modelformset_factory
-from django.http import Http404, HttpResponseRedirect
-from django.shortcuts import render_to_response, get_object_or_404
-from django.template import RequestContext
-from django.utils.translation import ugettext as _
+from django.http import Http404, HttpResponse, HttpResponseRedirect
+from django.shortcuts import render, get_object_or_404
+from django.utils.translation import ugettext as _, get_language
 from django.views.generic import TemplateView
 from django.views.generic.base import View
 from django.views.generic.list import ListView as DjangoListView
 
-from djaloha import utils as djaloha_utils
+from coop_html_editor import utils as html_editor_utils
 
-logger = logging.getLogger("coop_cms")
+from coop_cms.exceptions import ArticleNotAllowed
+from coop_cms.logger import logger
+from coop_cms.moves import reverse, is_authenticated
+from coop_cms.settings import is_cache_enabled
 
 
 class ListView(DjangoListView):
@@ -41,7 +42,7 @@ class ListView(DjangoListView):
 
 
 class EditableObjectView(View):
-    """Base class for aloha-editable objects"""
+    """Base class for html-inline editable objects"""
     model = None
     template_name = ""
     form_class = None
@@ -50,12 +51,27 @@ class EditableObjectView(View):
     varname = "object"
     object = None
     form = None
+    cache_enabled = None
+
+    def is_cache_enabled(self):
+        """check if cache is enable for this view"""
+        if self.cache_enabled is None:
+            return is_cache_enabled()
+        return self.cache_enabled
+
+    def can_cache(self):
+        """check if content can be set/get from cache"""
+        if self.can_edit_object():
+            # Never cache for editors
+            return False
+
+        return self.is_cache_enabled()
 
     def can_edit_object(self):
         """check edit perms"""
         can_edit_perm = 'can_edit_{0}'.format(self.varname)
         user = self.request.user
-        return user.is_authenticated() and user.is_active and user.has_perm(can_edit_perm, self.object)
+        return is_authenticated(user) and user.is_active and user.has_perm(can_edit_perm, self.object)
         
     def can_access_object(self):
         """check access perms: 404 if not"""
@@ -80,13 +96,13 @@ class EditableObjectView(View):
             'form': self.form if self.edit_mode else None,
             'editable': self.can_edit_object(),
             'edit_mode': self.edit_mode,
-            'title': getattr(self.object, 'title', unicode(self.object)),
+            'title': getattr(self.object, 'title', '{0}'.format(self.object)),
             'coop_cms_edit_url': self.get_edit_url(),
             'coop_cms_cancel_url': self.get_cancel_url(),
             'coop_cms_can_view_callback': self.can_view_object,
             'coop_cms_can_edit_callback': self.can_edit_object,
             self.varname: self.object,
-            'raw_'+self.varname: self.object,
+            'raw_' + self.varname: self.object,
         }
         
     def get_edit_url(self):
@@ -107,9 +123,27 @@ class EditableObjectView(View):
     def handle_object_not_found(self):
         """called if object not found"""
         pass
-    
+
+    def get_form_class(self):
+        return self.form_class
+
+    def get_form_kwargs(self):
+        return {}
+
+    def get_form(self, *args, **kwargs):
+        kwargs.update(self.get_form_kwargs())
+        form_class = self.get_form_class()
+        return form_class(*args, **kwargs)
+
+    def get_cache_key(self, obj):
+        language = get_language()
+        class_name = '{0}.{1}'.format(obj.__class__.__module__, obj.__class__.__name__)
+        cache_key = '{0}-{1}-{2}-{3}'.format(settings.SITE_ID, language, class_name, obj.id)
+        return cache_key
+
     def get(self, request, *args, **kwargs):
         """handle http get -> view"""
+
         try:
             self.object = self.get_object()
         except Http404:
@@ -118,22 +152,32 @@ class EditableObjectView(View):
                 return return_this
             else:
                 raise
-        
+
         if not self.can_access_object():
             raise Http404
         
         if not self.can_view_object():
             logger.warning("PermissionDenied")
             raise PermissionDenied
+
+        if self.can_cache():
+            response_content = cache.get(self.get_cache_key(self.object))
+            if response_content:
+                return HttpResponse(response_content)
         
-        self.form = self.form_class(instance=self.object)
+        self.form = self.get_form(instance=self.object)
         
-        return render_to_response(
+        response = render(
+            request,
             self.get_template(),
-            self.get_context_data(),
-            context_instance=RequestContext(request)
+            self.get_context_data()
         )
-    
+
+        if response.status_code == 200 and self.can_cache():
+            cache.set(self.get_cache_key(self.object), response.content)
+
+        return response
+
     def after_save(self, object):
         """called after save"""
         pass
@@ -141,39 +185,46 @@ class EditableObjectView(View):
     def post(self, request, *args, **kwargs):
         """handle http post -> edit"""
         if not self.edit_mode:
-            raise Http404
+            raise ArticleNotAllowed
         
         self.object = self.get_object()
         
         if not self.can_edit_object():
-            logger.warning("PermissionDenied")
+            # logger.warning("PermissionDenied")
             raise PermissionDenied
-        
-        self.form = self.form_class(request.POST, request.FILES, instance=self.object)
 
-        forms_args = djaloha_utils.extract_forms_args(request.POST)
-        djaloha_forms = djaloha_utils.make_forms(forms_args, request.POST)
+        self.form = self.get_form(request.POST, request.FILES, instance=self.object)
+
+        forms_args = html_editor_utils.extract_forms_args(request.POST)
+        inline_html_forms = html_editor_utils.make_forms(forms_args, request.POST)
+
+        if self.form.is_valid() and all([_form.is_valid() for _form in inline_html_forms]):
+
+            if self.is_cache_enabled():
+                cache.delete(self.get_cache_key(self.object))
 
-        if self.form.is_valid() and all([f.is_valid() for f in djaloha_forms]):
             self.object = self.form.save()
             
             self.after_save(self.object)
             
-            if djaloha_forms:
-                [f.save() for f in djaloha_forms]
+            if inline_html_forms:
+                [_the_form.save() for _the_form in inline_html_forms]
 
-            success_message(request, _(u'The object has been saved properly'))
+            success_message(request, _('The object has been saved properly'))
 
             return HttpResponseRedirect(self.object.get_absolute_url())
         else:
-            error_text = u'<br />'.join([unicode(f.errors) for f in [self.form]+djaloha_forms if f.errors])
-            error_message(request, _(u'An error occured: {0}').format(error_text))
-            logger.debug(u"error: {0}".format(error_text))
+
+            error_text = '<br />'.join(
+                ['{0}'.format(_form.errors) for _form in [self.form] + inline_html_forms if _form.errors]
+            )
+            error_message(request, _('An error occurred: {0}').format(error_text))
+            logger.debug("error: {0}".format(error_text))
     
-        return render_to_response(
+        return render(
+            request,
             self.get_template(),
-            self.get_context_data(),
-            context_instance=RequestContext(request)
+            self.get_context_data()
         )
 
 
@@ -193,7 +244,7 @@ class EditableFormsetView(TemplateView):
         ct = ContentType.objects.get_for_model(self.model)
         can_edit_perm = '{0}.change_{1}'.format(ct.app_label, ct.model)
         user = self.request.user
-        return user.is_authenticated() and user.is_active and user.has_perm(can_edit_perm, None)
+        return is_authenticated(user) and user.is_active and user.has_perm(can_edit_perm, None)
         
     def can_view_objects(self):
         """check view perms"""
@@ -247,8 +298,8 @@ class EditableFormsetView(TemplateView):
     
     def get_formset(self, *args, **kwargs):
         """formset"""
-        Formset = self.get_formset_class()
-        return Formset(queryset=self.get_queryset(), *args, **kwargs)
+        formset_class = self.get_formset_class()
+        return formset_class(queryset=self.get_queryset(), *args, **kwargs)
     
     def get(self, request, *args, **kwargs):
         """handle http get --> view"""
@@ -256,10 +307,10 @@ class EditableFormsetView(TemplateView):
             raise PermissionDenied
             
         self.formset = self.get_formset()
-        return render_to_response(
+        return render(
+            request,
             self.get_template(),
-            self.get_context_data(),
-            context_instance=RequestContext(request)
+            self.get_context_data()
         )
     
     def _pre_save_object(self, form):
@@ -277,13 +328,13 @@ class EditableFormsetView(TemplateView):
     
         if not self.can_edit_objects():
             raise PermissionDenied
-        
+
         self.formset = self.get_formset(request.POST, request.FILES)
         
-        forms_args = djaloha_utils.extract_forms_args(request.POST)
-        djaloha_forms = djaloha_utils.make_forms(forms_args, request.POST)
+        forms_args = html_editor_utils.extract_forms_args(request.POST)
+        inline_html_forms = html_editor_utils.make_forms(forms_args, request.POST)
 
-        #Handle case where formset post data has value which are not in the queryset
+        # Handle case where formset post data has value which are not in the queryset
         formset_index_error = False
         try:
             formset_is_valid = self.formset.is_valid()
@@ -291,32 +342,32 @@ class EditableFormsetView(TemplateView):
             formset_index_error = True
             formset_is_valid = False
 
-        if formset_is_valid and all([f.is_valid() for f in djaloha_forms]):
+        if formset_is_valid and all([_form.is_valid() for _form in inline_html_forms]):
             for form in self.formset:
                 if self._pre_save_object(form):
                     obj = form.save()
                     self._post_save_object(obj, form)
             
-            if djaloha_forms:
-                [f.save() for f in djaloha_forms]
+            if inline_html_forms:
+                [_html_form.save() for _html_form in inline_html_forms]
             
-            success_message(request, _(u'The objects have been saved properly'))
+            success_message(request, _('The objects have been saved properly'))
 
             url = self.get_success_url()
             return HttpResponseRedirect(url)
         else:
             if formset_index_error:
-                logger.warning(_(u'Index error in formset: some objects may be missing'))
-                error_message(request, _(u'An error occured: At least one object is missing. Please try again.'))
+                logger.warning(_('Index error in formset: some objects may be missing'))
+                error_message(request, _('An error occured: At least one object is missing. Please try again.'))
                 return HttpResponseRedirect(self.get_cancel_url())
             else:
-                for f in self.formset:
-                    errors = f.errors
+                for _form in self.formset:
+                    errors = _form.errors
                     if errors:
                         logger.warning(errors)
         
-        return render_to_response(
+        return render(
+            request,
             self.get_template(),
-            self.get_context_data(),
-            context_instance=RequestContext(request)
+            self.get_context_data()
         )
