@@ -11,8 +11,8 @@ from coop_cms.settings import is_localized
 
 class Command(BaseCommand):
     """patch alias redirect"""
-    help = u"patch alias redirect"
-
+    help = "patch alias redirect"
+    use_argparse = False
 
     def handle(self, *args, **options):
         """command"""
@@ -20,7 +20,7 @@ class Command(BaseCommand):
         verbose = options.get('verbosity', 1)
         
         if not is_localized():
-            print "the site is not localized this is not required"
+            print("the site is not localized this is not required")
         
         from modeltranslation.utils import build_localized_fieldname
         
@@ -30,7 +30,7 @@ class Command(BaseCommand):
             cursor.execute(
                 '''SELECT path, redirect_url FROM coop_cms_alias where id={0}'''.format(alias.id))
             row = cursor.fetchone()
-            print row
+            print(row)
             (path, redirect_url) = row
             
             languages = [x for (x, y) in settings.LANGUAGES]
@@ -39,7 +39,7 @@ class Command(BaseCommand):
             path_field_name = build_localized_fieldname('path', lang_code)
             redirect_url_field_name = build_localized_fieldname('redirect_url', lang_code)
             if (not getattr(alias, path_field_name)) and (not getattr(alias, redirect_url_field_name)):
-                print "update", alias.id, path, redirect_url
+                print("update", alias.id, path, redirect_url)
                 setattr(alias, path_field_name, path)
                 setattr(alias, redirect_url_field_name, redirect_url)
                 alias.save()
